@@ -4,7 +4,13 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
+
+sub ver {
+    return $VERSION;
+}
+1;
+__END__
 
 =head1 NAME
 
